Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/coolgirl-multicart/coolgirl-multirom-builder.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAlexey 'Cluster' Avdyukhin <clusterrr@clusterrr.com>2021-05-26 04:23:42 +0300
committerAlexey 'Cluster' Avdyukhin <clusterrr@clusterrr.com>2021-05-26 04:23:42 +0300
commite672ebcb73b042354ea4e6cbc0e95789cb44ffb0 (patch)
treef48b11e33bda13c2f656cf31ff65724e401fa031 /preloader.asm
parent7c48ca9422e7024b84ea905ff6753fe38d5542c3 (diff)
Fixes
Diffstat (limited to 'preloader.asm')
-rw-r--r--preloader.asm11
1 files changed, 6 insertions, 5 deletions
diff --git a/preloader.asm b/preloader.asm
index 5e1be9e..bf92839 100644
--- a/preloader.asm
+++ b/preloader.asm
@@ -51,15 +51,15 @@ start_game:
lda #HIGH(string_incompatible_console)
sta <COPY_SOURCE_ADDR+1
jsr print_text
- bit PPUSTATUS
- lda #0
- sta PPUSCROLL
- sta PPUSCROLL
lda #%00001000
sta PPUCTRL
lda #%00001010
sta PPUMASK
- ; wait until all buttons released
+ ; disable scrolling
+ inc SCROLL_LOCK
+ ; dim-in
+ jsr dim_base_palette_in
+; wait until all buttons released
.incompatible_print_wait_no_button:
jsr read_controller
lda <BUTTONS
@@ -75,6 +75,7 @@ start_game:
jsr read_controller
lda <BUTTONS
beq .incompatible_print_wait_button
+ jsr dim_base_palette_out
jmp Start
compatible_console: